package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.SearchContent;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.mapper.SearchContentMapper;
import com.ruoyi.system.service.ISearchContentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-08-19
 */
@Service
public class SearchContentServiceImpl implements ISearchContentService 
{
    @Autowired
    private SearchContentMapper searchContentMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public SearchContent selectSearchContentById(String id)
    {
        return searchContentMapper.selectSearchContentById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param searchContent 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<SearchContent> selectSearchContentList(SearchContent searchContent)
    {
        return searchContentMapper.selectSearchContentList(searchContent);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param searchContent 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertSearchContent(SearchContent searchContent)
    {
        searchContent.setCreateTime(DateUtils.getNowDate());
        return searchContentMapper.insertSearchContent(searchContent);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param searchContent 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateSearchContent(SearchContent searchContent)
    {
        return searchContentMapper.updateSearchContent(searchContent);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteSearchContentByIds(String[] ids)
    {
        return searchContentMapper.deleteSearchContentByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteSearchContentById(String id)
    {
        return searchContentMapper.deleteSearchContentById(id);
    }
}
